Module: Pliny::CanonicalLogLineHelpers
- Included in:
- Middleware::CanonicalLogLine::LogLine
- Defined in:
- lib/pliny/canonical_log_line_helpers.rb
Overview
Helpers to produce a canonical log line. This mostly amounts to a set of accessors that do basic type checking combined with tracking an internal schema so that we can produce a hash of everything that’s been set so far.
Defined Under Namespace
Modules: ClassMethods
Class Method Summary collapse
Instance Method Summary collapse
Class Method Details
.included(klass) ⇒ Object
22 23 24 |
# File 'lib/pliny/canonical_log_line_helpers.rb', line 22 def self.included(klass) klass.extend(ClassMethods) end |
Instance Method Details
#to_h ⇒ Object
26 27 28 |
# File 'lib/pliny/canonical_log_line_helpers.rb', line 26 def to_h @values end |